package md

type MqQueue struct {
	ExchangeName   string `json:"exchangeName"`     //交换机名字
	Name           string `json:"name"`             //队列名字
	Type           string `json:"type"`             //队列类型
	IsPersistent   bool   `json:"is_persistent"`    //队列是否持久化
	RoutKey        string `json:"rout_key"`         //路由
	BindKey        string `json:"bind_key"`         //绑定的路由
	ConsumeFunName string `json:"consume_fun_name"` //消费方法
}

var RabbitMqQueueKeyList = []*MqQueue{
	{
		ExchangeName:   "egg.energy",
		Name:           "egg_energy_star_level_dividend_queue",
		Type:           TopicQueueType,
		IsPersistent:   false,
		RoutKey:        "star_level_dividend",
		BindKey:        "",
		ConsumeFunName: "EggEnergyStartLevelDividendConsume",
	},
	{
		ExchangeName:   "egg.energy",
		Name:           "egg_energy_fund_data_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "fund_data",
		BindKey:        "",
		ConsumeFunName: "EggEnergyDealFundDataConsume",
	},
	{
		ExchangeName:   "egg.energy",
		Name:           "egg_energy_platform_revenue_data_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "platform_revenue_data",
		BindKey:        "",
		ConsumeFunName: "EggEnergyDealPlatformRevenueDataConsume",
	},
	{
		ExchangeName:   "egg.energy",
		Name:           "egg_deal_user_virtual_coin_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "deal_user_virtual_coin",
		BindKey:        "",
		ConsumeFunName: "EggEnergyDealUserVirtualCoinDataConsume",
	},
	{
		ExchangeName:   "im.egg.energy",
		Name:           "im_egg_energy_batch_send_message_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "batch_send_message_data",
		BindKey:        "",
		ConsumeFunName: "IMEggEnergyBatchSendMessageDataConsume",
	},
	{
		ExchangeName:   "im.egg.energy",
		Name:           "im_egg_energy_del_friend_comment_circle_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "del_friend_circle_comment_data",
		BindKey:        "",
		ConsumeFunName: "IMEggEnergyDelFriendCircleDataConsume",
	},
	{
		// 消费临时队列
		ExchangeName: "egg.app",
		Name:         "egg_auto_score_test_queue",
		//Name:           "egg_auto_score_queue",
		Type:         DirectQueueType,
		IsPersistent: false,
		//RoutKey:        "egg_auto_score",
		RoutKey:        "egg_auto_score_test",
		BindKey:        "",
		ConsumeFunName: "EggEnergyAutoScoreConsume",
	},
	{
		ExchangeName:   "egg.app",
		Name:           "egg_slow_auto_up_lv",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_slow_auto_up_lv",
		BindKey:        "",
		ConsumeFunName: "EggSlowAutoUpLvConsume",
	},
	{
		ExchangeName:   "egg.canal.topic",
		Name:           "egg_energy_user_activity",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_energy_user_activity",
		BindKey:        "",
		ConsumeFunName: "EggEnergyUserActivityConsume",
	},
	{
		ExchangeName:   "egg.canal.topic",
		Name:           "egg_canal_user",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_canal_user",
		BindKey:        "",
		ConsumeFunName: "EggCanalUserConsume",
	},
	{
		ExchangeName:   "egg.energy",
		Name:           "egg_energy_team_assistance_back",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_energy_team_assistance",
		BindKey:        "",
		ConsumeFunName: "EggEnergyTeamAssistanceConsume",
	},
	{
		ExchangeName:   "egg.canal.topic",
		Name:           "egg_user_virtual_coin_flow_aggregation",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_canal_user_virtual_coin_flow",
		BindKey:        "",
		ConsumeFunName: "EggCanalUserVirtualCoinFlowAggregationConsume",
	},
	{
		ExchangeName:   "egg.app",
		Name:           "egg_send_friend_circle_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_send_friend_circle",
		BindKey:        "",
		ConsumeFunName: "EggSendFriendCircleDataConsume",
	},
	{
		ExchangeName:   "egg.app",
		Name:           "egg_comment_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_comment",
		BindKey:        "",
		ConsumeFunName: "EggCommentDataConsume",
	},
	{
		ExchangeName:   "egg.canal.topic",
		Name:           "egg_canal_energy_exchange_account_queue",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "egg_canal_user_wallet_flow",
		BindKey:        "",
		ConsumeFunName: "EggCanalEnergyExchangeAccountConsume",
	},
}

const (
	EggSlowAutoUpLvConsume                               = "EggSlowAutoUpLvConsume"
	EggEnergyUserActivityConsume                         = "EggEnergyUserActivityConsume"
	EggCanalUserConsume                                  = "EggCanalUserConsume"
	JpushRecordFunName                                   = "JpushRecordConsume"
	AliyunSmsRecordFunName                               = "AliyunSmsRecordConsume"
	EggEnergyStartLevelDividendFunName                   = "EggEnergyStartLevelDividendConsume"
	EggEnergyDealFundDataFunName                         = "EggEnergyDealFundDataConsume"
	EggEnergyDealPlatformRevenueDataFunName              = "EggEnergyDealPlatformRevenueDataConsume"
	EggEnergyDealUserVirtualCoinDataFunName              = "EggEnergyDealUserVirtualCoinDataConsume"
	IMEggEnergyBatchSendMessageDataFunName               = "IMEggEnergyBatchSendMessageDataConsume"
	IMEggEnergyDelFriendCircleDataFunName                = "IMEggEnergyDelFriendCircleDataConsume"
	EggFinWithdrawApplyDataConsumeFunName                = "EggFinWithdrawApplyDataConsume"
	EggEnergySettlementPublicGiveActivityCoinFunName     = "EggEnergySettlementPublicGiveActivityCoinConsume"
	EggEnergyStartExchangeGreenEnergyFunName             = "EggEnergyStartExchangeGreenEnergyConsume"
	EggEnergyAutoExchangeGreenEnergyFunName              = "EggEnergyAutoExchangeGreenEnergyConsume"
	EggEnergyNewUserRegisterDataFunName                  = "EggEnergyNewUserRegisterDataConsume"
	EggEnergyDealUserECPMFunName                         = "EggEnergyDealUserECPMConsume"
	EggCanalInviteUserNumsFunName                        = "EggCanalInviteUserNumsConsume"
	EggCanalViolateNumsFunName                           = "EggCanalViolateNumsConsume"
	IMEggEnergySendRedPackageFunName                     = "IMEggEnergySendRedPackageConsume"
	EggRecordActiveDataFunName                           = "EggRecordActiveDataConsume"
	EggCanalPersonAddActivityValueFunName                = "EggCanalPersonAddActivityValueConsume"
	VideoRewardFunName                                   = "VideoRewardFunName"
	PlayletRewardFunName                                 = "PlayletRewardFunName"
	UserDeleteFunName                                    = "UserDeleteConsume"
	EggEnergyAutoScoreDataFunName                        = "EggEnergyAutoScoreConsume"
	PublicPlatoonUserRelationCommissionConsumeFunName    = "AddPublicPlatoonUserRelationCommissionConsume"
	EggEnergyTeamAssistanceConsumeFunName                = "EggEnergyTeamAssistanceConsume"
	EggCanalUserVirtualCoinFlowAggregationConsumeFunName = "EggCanalUserVirtualCoinFlowAggregationConsume"
	EggSendFriendCircleDataFunName                       = "EggSendFriendCircleDataConsume"
	EggCanalEnergyExchangeAccountFunName                 = "EggCanalEnergyExchangeAccountConsume"
	EggCommentDataFunName                                = "EggCommentDataConsume"
)
